#!/usr/bin/python

################################################################
#                                                              #
# Blue Team Training Toolkit (BT3)                             #
# written by Juan J. Guelfo @ Encripto AS                      #
# post@encripto.no                                             #
#                                                              #
# Copyright 2013-2016 Encripto AS. All rights reserved.        #
#                                                              #
# BT3 is licensed under the FreeBSD license.                   #
# http://www.freebsd.org/copyright/freebsd-license.html        #
#                                                              #
################################################################


import time, os, sys, re, subprocess, ipcalc
import libs.bt3out


def allow_keyboard_interrupt(s, f):
    print("\n")
    libs.bt3out.print_warning("CTRL+C was pressed. Aborting...\n")
    raise KeyboardInterrupt


def prevent_keyboard_interrupt(s, f):
    print("\n")
    libs.bt3out.print_info("Please, use \"exit\" instead.")


def get_confirmation(msg):
    c = ""
    options = ["Y", "N", "y", "n"]
    while c not in options:
        time.sleep(0.5)
        print("")
        libs.bt3out.print_warning(msg)
        c = raw_input("    Would you like to continue? [Y/N]: ")
        print("")
        if c.upper() == "N":
            return False

        elif c.upper() == "Y":
            return True


def check_file_exists(filename):
    return os.path.exists(filename) and os.path.isfile(filename)


def check_mac_address(mac):
    return re.match("[0-9a-f]{2}([:])[0-9a-f]{2}(\\1[0-9a-f]{2}){4}$", mac.lower())


def check_ip_address(ip):
    legal = False
    try:
        subnet = ipcalc.Network(ip)
        legal = True

    except ValueError:
        legal = False

    return legal


def check_legal_fqdn(fqdn):
    reg = None
    legal = False
    try:
        if len(fqdn) > 0 and len(fqdn) < 255:
            if fqdn[-1] in ["."]:
                fqdn = fqdn[:-1]

            reg = re.compile("(?!-)[A-Z\d-]{1,63}(?<!-)$", re.IGNORECASE)
            legal = all(reg.match(v) for v in fqdn.split("."))
    except:
        legal = False

    return legal


def check_host_value(host):
    legal_ip = check_ip_address(host)
    legal_fqdn = check_legal_fqdn(host)
    legal_host = True

    if not legal_ip and not legal_fqdn:
        legal_host = False
    
    return legal_host

    
def check_legal_port(port):
    legal_port = True
    if int(port) < 1 or int(port) > 65535:
        legal_port = False
     
    return legal_port


def check_network_interface(interface):
    cmd = "ifconfig -a"
    output = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE).communicate()[0]
    result = str(output).find(interface)

    return result > -1
