#!/usr/bin/python

################################################################
#                                                              #
# Blue Team Training Toolkit (BT3)                             #
# written by Juan J. Guelfo @ Encripto AS                      #
# post@encripto.no                                             #
#                                                              #
# Copyright 2013-2016 Encripto AS. All rights reserved.        #
#                                                              #
# BT3 is licensed under the FreeBSD license.                   #
# http://www.freebsd.org/copyright/freebsd-license.html        #
#                                                              #
################################################################


import os, sys, random
import libs.bt3in


def print_ok(msg):
    print("\033[1;32m[+]\033[1;m {0}".format(msg))


def print_warning(msg):
    print("\033[1;33m[!]\033[1;m {0}".format(msg))

def print_error(msg):
    print("\033[1;31m[-]\033[1;m {0}".format(msg))


def print_info(msg):
    print("\033[1;34m[*]\033[1;m {0}".format(msg))


def print_title(msg):
    print("\033[1;37m{0}\033[1;m".format(msg))


def print_prompt(module_name):
    prompt = None
    if module_name:
        prompt = "\033[1;37m{0} ~ \033[1;m\033[1;34m{1}\033[1;m\033[1;37m{2}\033[1;m".format("BT3", "%s" % module_name, " > " )
    else:
        prompt = "\033[1;37m{0}\033[1;m".format("BT3 > ")

    return prompt


def exit_program(args):
    print("")
    print_info("BT3 is now shutting down...\n")
    sys.exit()


def print_help(help_content, error, command):
    print("")
    if error:
        print_error("Command not found. Did you mean...?\n")

    width = [16, 16]
    help_lines = []
    
    if command:
        help_lines.append(["Command", "Description"])
        help_lines.append(["-------", "-----------"])
    
    else:
        help_lines.append(["Module", "Description"])
        help_lines.append(["------", "-----------"])
        
    for cmd in help_content:
        index = 0
        line = []
        for value in cmd:
            if value:
                current_width = len(str(value))
                line.append(str(value))
                if width[index] < current_width:
                    width[index] = current_width + 2
                index += 1

        help_lines.append(line)

    for line in help_lines:
        print("    %-*s  %-*s" % (width[0], str(line[0]), width[1], str(line[1])))

    print("")


def print_profiles(content):
    print("")
    width = [16, 16]
    content_lines = []
    
    content_lines.append(["Profile", "Description"])
    content_lines.append(["-------", "-----------"])
    
    for prof in content:
        index = 0
        line = []
        for value in prof:
            if value:
                current_width = len(str(value))
                line.append(str(value))
                if width[index] < current_width:
                    width[index] = current_width + 2
                index += 1

        content_lines.append(line)

    for line in content_lines:
        print("    %-*s  %-*s" % (width[0], str(line[0]), width[1], str(line[1])))

    print("")
    

def print_options(options):
    print("")
    width = [16, 10, 10, 10]
    option_lines = []
    option_lines.append(["Name", "Setting", "Required", "Description"])
    option_lines.append(["----", "-------", "--------", "-----------"])
    for option in options:
        index = 0
        line = []
        for value in option:
            current_width = len(str(value))
            line.append(str(value))
            if width[index] < current_width:
                width[index] = current_width + 2
            index += 1

        option_lines.append(line)

    for line in option_lines:
        print("    %-*s  %-*s  %-*s  %-*s" % (width[0], str(line[0]), width[1], str(line[1]),
                                              width[2], str(line[2]), width[3], str(line[3])))

    print("")
    

def print_banner(version, author):
    os.system("clear")
    if random.randint(1, 10) % 2 == 0:
        print("                                                                                          ")
        print("\033[1;34m              ____  _              _____                                \033[1;m")
        print("\033[1;34m             | __ )| |_   _  ___  |_   _|__  __ _ _ __ ___              \033[1;m")
        print("\033[1;34m             |  _ \| | | | |/ _ \   | |/ _ \/ _` | '_ ` _ \             \033[1;m")
        print("\033[1;34m             | |_) | | |_| |  __/   | |  __/ (_| | | | | | |            \033[1;m")
        print("\033[1;34m             |____/|_|\__,_|\___|   |_|\___|\__,_|_| |_| |_|            \033[1;m")
        print("                                                                                          ")
        print("\033[1;34m  _____          _       _               _____           _ _    _ _     \033[1;m")
        print("\033[1;34m |_   _| __ __ _(_)_ __ (_)_ __   __ _  |_   _|__   ___ | | | _(_) |_   \033[1;m")
        print("\033[1;34m   | || '__/ _` | | '_ \| | '_ \ / _` |   | |/ _ \ / _ \| | |/ / | __|  \033[1;m")
        print("\033[1;34m   | || | | (_| | | | | | | | | | (_| |   | | (_) | (_) | |   <| | |_   \033[1;m")
        print("\033[1;34m   |_||_|  \__,_|_|_| |_|_|_| |_|\__, |   |_|\___/ \___/|_|_|\_\_|\__|  \033[1;m")
        print("\033[1;34m                                 |___/                                  \033[1;m")
        print("                                                                                          ")
        
    else:
        print("                                                                                          ")
        print("\033[1;34m                  ______       _________    \033[1;m\033[1;37m  ______  \033[1;m")
        print("\033[1;34m                 |_   _ \     |  _   _  |   \033[1;m\033[1;37m / ____ `.\033[1;m")
        print("\033[1;34m                   | |_) |    |_/ | | \_|   \033[1;m\033[1;37m `'  __) |\033[1;m")
        print("\033[1;34m                   |  __'.        | |       \033[1;m\033[1;37m _  |__ '.\033[1;m")
        print("\033[1;34m                  _| |__) |      _| |_      \033[1;m\033[1;37m| \____) |\033[1;m")
        print("\033[1;34m                 |_______/      |_____|     \033[1;m\033[1;37m \______.'\033[1;m")
        print("                                                                                          ")

    
    print("                                                                                              ")
    print("\033[1;37m ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^     \033[1;m")
    print("                                                                                              ")
    print("\033[1;32m                 Blue Team Training Toolkit (BT3) v{0}                      \033[1;m".format(version))
    print("\033[1;32m           {0}                                                              \033[1;m".format(author))
    print("                                                                                              ")
    print("\033[1;37m ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^     \033[1;m")
    print("                                                                                              ")
    print("                                                                                              ")
