#!/usr/bin/python

################################################################
#                                                              #
# Blue Team Training Toolkit (BT3)                             #
# written by Juan J. Guelfo @ Encripto AS                      #
# post@encripto.no                                             #
#                                                              #
# Copyright 2013-2016 Encripto AS. All rights reserved.        #
#                                                              #
# BT3 is licensed under the FreeBSD license.                   #
# http://www.freebsd.org/copyright/freebsd-license.html        #
#                                                              #
################################################################


import cmd, sys, signal
import libs.bt3in, libs.bt3out, libs.bt3ver
import modules.maligno, modules.pcapteller


class Menu(cmd.Cmd):

    def __init__(self):
        cmd.Cmd.__init__(self)
        self.maligno_menu = modules.maligno.Menu()
        self.pcapteller_menu = modules.pcapteller.Menu()


    def complete_show(self, text, line, begidx, endidx):
        return [i for i in ["modules"] if i.startswith(text)]
        
        
    def complete_use(self, text, line, begidx, endidx):
        return [i for i in ["maligno", "pcapteller"] if i.startswith(text)]


    def default(self, args):
        print("")
        libs.bt3out.print_error("Command not found. Type \"help\" if you need assistance.\n")


    def do_back(self, args):
        pass


    def do_bt3update(self, args):
        print("")
        libs.bt3ver.check_for_updates(libs.bt3ver.__version__)

    
    def do_exit(self, args):
        libs.bt3out.exit_program(args)
    

    def do_help(self, args):
        cmds = [["back", "Exit current selected module and return to main menu."],
                ["bt3update", "Check for software updates."],
                ["exit", "Exit the Blue Team Training Toolkit."],        
                ["help", "Display help menu."],
                ["show modules", "Display supported application modules."],
                ["use <module>", "Select an application module."],
                ["version", "Display software version."]]
        libs.bt3out.print_help(cmds, False, True)


    def do_show(self, args):
        if args.upper() in ["MODULES"]:
            cmds = [["maligno", "Attack simulation with customized malware indicators."],
                    ["pcapteller", "Network traffic manipulation and replay."]]
            libs.bt3out.print_help(cmds, False, False)

        else:
            cmds = [["show modules", "Display supported application modules."]]
            libs.bt3out.print_help(cmds, True, True)


    def do_use(self, args):
        if args.upper() in ["MALIGNO"]:
            self.maligno_menu.prompt = libs.bt3out.print_prompt("maligno")
            self.maligno_menu.cmdloop()
            
        elif args.upper() in ["PCAPTELLER"]:
            self.pcapteller_menu.prompt = libs.bt3out.print_prompt("pcapteller")
            self.pcapteller_menu.cmdloop()

        else:
            cmds = [["use maligno", "Use maligno module."],
                    ["use pcapteller", "Use pcapteller module."]]
            libs.bt3out.print_help(cmds, True, True)


    def do_version(self, args):
        print("")
        libs.bt3out.print_info("You are running %s version %s\n" % ("Blue Team Training Toolkit (BT3)", libs.bt3ver.__version__))


    def emptyline(self):
        pass
    
   
   

